@@ -1,5 +1,8 @@
 context("get")
 
+skip_if(solr_missing(conn))
+skip_on_ci()
+
 test_that("get works with a single id", {
   skip_on_cran()
 
