@@ -1,5 +1,8 @@
 context("update_atomic_json")
 
+skip_if(solr_missing(conn))
+skip_on_ci()
+
 test_that("update_atomic_json works", {
   skip_on_cran()
 
